@@ -1,5 +1,5 @@
 use f32 as dp; // dimension
-use crate::cprelude;
+pub use crate::cprelude::*;
 
 use auto_ops::*;
 pub struct Point {
@@ -18,7 +18,7 @@ impl Point {
             .sqrt()
     }
 }
-impl cprelude::CloseEnough for Point {
+impl CloseEnough for Point {
     fn is_close_enough_to(&self, other: &Self, tolerance: dp) -> bool {
         self.distance_to(other) <= tolerance
     }
